@@ -1,4 +1,6 @@
+from __future__ import absolute_import
 from django.contrib.auth.backends import RemoteUserBackend
+from .compat import from_wsgi_safe_string
 
 class WebtestUserBackend(RemoteUserBackend):
     """ Auth backend for django-webtest auth system """
@@ -6,3 +8,6 @@ class WebtestUserBackend(RemoteUserBackend):
     def authenticate(self, django_webtest_user):
         return super(WebtestUserBackend, self).authenticate(django_webtest_user)
 
+    def clean_username(self, username):
+        return from_wsgi_safe_string(username)
+
